import BN from 'bn.js';
/**
 * Analogous to Number.toFixed() for BN values. Example
 *
 * @example bnToFixed(new BN(123), 2, 5) === '1.23000'; // true
 *
 * @param {BN} num on-chain integer representation
 * @param {number} decimals number of decimals
 * @param {number} precision optional precision, same as in Number.toFixed()
 */
export declare const bnToFixed: (num: BN, decimals: number, precision?: number | undefined) => string;
/**
 * Turn a decimal number into its on-chain integer representation.
 *
 * @example toDecimalPaddedString('1.23', 2) === '123'
 *
 * @param val A number as a string
 * @param decimals Number of decimals
 * @returns BN of the number
 */
export declare const toDecimalPaddedString: (val: string, decimals?: number | undefined) => string;
